|pipeline status| |coverage report|

Tupak
=====

Fulfilling all your gravitational wave dreams.

-  `Installation
   instructions <https://monash.docs.ligo.org/tupak/installation.html>`__
-  `Documentation <https://monash.docs.ligo.org/tupak/index.html>`__.
-  `Issue tracker <https://git.ligo.org/Monash/tupak/issues>`__

We encourage you to contribute to the development via a merge request.  For
help in creating a merge request, see `this page
<https://docs.gitlab.com/ee/gitlab-basics/add-merge-request.html>`__ or contact
us directly.

Examples
--------

To get started with ``tupak``, we have a few examples and tutorials:

1. `Examples of injecting and recovering
   data <https://git.ligo.org/Monash/tupak/tree/master/examples/injection_examples>`__

   -  `A basic
      tutorial <https://git.ligo.org/Monash/tupak/blob/master/examples/injection_examples/basic_tutorial.py>`__
   -  `Create your own source
      model <https://git.ligo.org/Monash/tupak/blob/master/examples/injection_examples/create_your_own_source_model.py>`__
   -  `Create your own time-domain source
      model <https://git.ligo.org/Monash/tupak/blob/master/examples/injection_examples/create_your_own_time_domain_source_model.py>`__
   -  `How to specify the
      prior <https://git.ligo.org/Monash/tupak/blob/master/examples/injection_examples/how_to_specify_the_prior.py>`__
   -  `Using a partially marginalized
      likelihood <https://git.ligo.org/Monash/tupak/blob/master/examples/injection_examples/marginalized_likelihood.py>`__

2. `Examples using open
   data <https://git.ligo.org/Monash/tupak/tree/master/examples/open_data_examples>`__

   -  `Analysing the first Binary Black hole detection,
      GW150914 <https://git.ligo.org/Monash/tupak/blob/master/examples/open_data_examples/GW150914.py>`__

3. `Notebook-style
   tutorials <https://git.ligo.org/Monash/tupak/tree/master/examples/tutorials>`__

   -  `Comparing different
      samplers <https://git.ligo.org/Monash/tupak/blob/master/examples/tutorials/compare_samplers.ipynb>`__
   -  `Visualising the
      output <https://git.ligo.org/Monash/tupak/blob/master/examples/tutorials/visualising_the_results.ipynb>`__

.. |pipeline status| image:: https://git.ligo.org/Monash/tupak/badges/master/pipeline.svg
   :target: https://git.ligo.org/Monash/tupak/commits/master
.. |coverage report| image:: https://monash.docs.ligo.org/tupak/coverage_badge.svg
   :target: https://monash.docs.ligo.org/tupak/htmlcov/
